@@ -1,7 +1,6 @@
 from __future__ import unicode_literals
 
 import json
-import re
 
 from .common import InfoExtractor
 from ..utils import (
@@ -16,7 +15,7 @@ class DeezerBaseInfoExtractor(InfoExtractor):
         if not self.get_param('test'):
             self.report_warning('For now, this extractor only supports the 30 second previews. Patches welcome!')
 
-        mobj = re.match(self._VALID_URL, url)
+        mobj = self._match_valid_url(url)
         data_id = mobj.group('id')
 
         webpage = self._download_webpage(url, data_id)
