@@ -77,7 +77,7 @@ class PicartoIE(InfoExtractor):
 
         return {
             'id': channel_id,
-            'title': self._live_title(title.strip()),
+            'title': title.strip(),
             'is_live': True,
             'channel': channel_id,
             'channel_id': metadata.get('id'),
