@@ -35,7 +35,7 @@ class ProSiebenSat1BaseIE(InfoExtractor):
             })[0]
 
         if not self.get_param('allow_unplayable_formats') and video.get('is_protected') is True:
-            raise ExtractorError('This video is DRM protected.', expected=True)
+            self.report_drm(clip_id)
 
         formats = []
         if self._ACCESS_ID:
