@@ -40,17 +40,14 @@ class TouTvIE(RadioCanadaIE):
     }]
     _CLIENT_KEY = '90505c8d-9c34-4f34-8da1-3a85bdc6d4f4'
 
-    def _real_initialize(self):
-        email, password = self._get_login_info()
-        if email is None:
-            return
+    def _perform_login(self, username, password):
         try:
             self._access_token = self._download_json(
                 'https://services.radio-canada.ca/toutv/profiling/accounts/login',
                 None, 'Logging in', data=json.dumps({
                     'ClientId': self._CLIENT_KEY,
                     'ClientSecret': '34026772-244b-49b6-8b06-317b30ac9a20',
-                    'Email': email,
+                    'Email': username,
                     'Password': password,
                     'Scope': 'id.write media-validation.read',
                 }).encode(), headers={
@@ -74,7 +71,7 @@ class TouTvIE(RadioCanadaIE):
             })
         # IsDrm does not necessarily mean the video is DRM protected (see
         # https://github.com/ytdl-org/youtube-dl/issues/13994).
-        if not self._downloader.params.get('allow_unplayable_formats') and metadata.get('IsDrm'):
+        if not self.get_param('allow_unplayable_formats') and metadata.get('IsDrm'):
             self.report_warning('This video is probably DRM protected.', path)
         video_id = metadata['IdMedia']
         details = metadata['Details']
