@@ -168,14 +168,7 @@ class UdemyIE(InfoExtractor):
         self._handle_error(response)
         return response
 
-    def _real_initialize(self):
-        self._login()
-
-    def _login(self):
-        username, password = self._get_login_info()
-        if username is None:
-            return
-
+    def _perform_login(self, username, password):
         login_popup = self._download_webpage(
             self._LOGIN_URL, None, 'Downloading login popup')
 
